---
title: FAQ
---

## Problems and resolutions

### Capacity panels in Grafana are empty

To collect capacity informations, you need to have [OnCommand Unifier Manager](https://mysupport.netapp.com/documentation/productlibrary/index.html?productID=61373) installed and added in NAbox under _Harvest > Configured OCUM Servers_. If you only add the cluster to Harvest, you will see performance metrics only.

### Deployment of the OVA fails with NVRAM related error

Deploying in vCenter versions earlier than 6.7 can lead to errors
related to a _nvram_ file not found. You have to manually edit the
`.vmx` file in the datastore and remove the _nvram_ setting :
```
nvram = "ovf:/file/file3"
```

### Why do I get a HTTP error when adding a 7-mode system?
Check that you enabled TLS with `options tls.enable on`.
Also check the following options : `httpd.admin.access`, `httpd.admin.hostsequiv.enable`

### Why isn't Grafana alerting working?
Grafana 4 supports alerting only for queries that do not make
use of variables, so if you edit the panel and you see anything with a '$' sign
in the query used to fetch the metrics, alerting will not work.
What you can do, is create your own panels without tempate variables and use
it to alert.

## General questions

### Can I import metrics from another NAbox or ADVA?
Yes, you can import data if the new NAbox can connect to the old VA through SSH.

Use the console menu by connecting to the VMware console or SSH with `admin`
account, in `[4] Advanced/Maintenance` > `[3] Migrate data`.

You will need to provide the IP address of the source VA and valid `root`
credential.

### Can I get a root shell on the virtual appliance?

At your own risk, for troubleshooting or customizing purpose, you can access the
virtual appliance as root with the following password : `NetappGrafanaVA`. You
can change the `root` password from the web interface.

### Can I use NAbox for metrics other than NetApp's?

Yes, port `2003` is the standard port for Graphite and is open to the external
network

### Can I see what version of NAbox I am running?

The version is displayed on the console login screen. You can also click on the
NAbox icon on the web site in the upper left corner to get version information
for the products installed.

## Managing metrics

### I'm running out of space, how can I manually clean up ?

If you want to manually delete metrics from old systems or just because
you need the space, you can safely remove any file or directory in the
`/opt/graphite/storage/whisper/` directory. Anything you remove here
will then disappear from grafana itself, there is no other database or
registry. The basic structure is : 

`/opt/graphite/storage/whisper/netapp/perf/<Site>/<Cluster>/node/<Node>`
`/opt/graphite/storage/whisper/netapp/perf/<Site>/<Cluster>/svm/<SVM>`
`/opt/graphite/storage/whisper/netapp/capacity/<Site>/<Cluster>/node/<Node>`
`/opt/graphite/storage/whisper/netapp/capacity/<Site>/<Cluster>/svm/<SVM>`

Inside these various directories you will find sub-directories for volumes, lifs, aggregates, etc... You can use `rm -rf` to remove them.

### How do I purge old metrics that aren't used anymore?

By default, NAbox will purge metrics if they were not updated in 120 days.

If you want to change that delay you will need to edit the following file :

`/etc/cron.daily/purge-whisper` and change `120` for a different value.

To manually purge old metrics, you can run these command lines directly :

```basic
find /opt/graphite/storage/whisper -type f -mtime +120 -name \*.wsp -delete
find /opt/graphite/storage/whisper -depth -type d -empty -delete
```

### I do I prevent capacity waste by temporary FlexClone volumes?

By default, NAbox is configured to blacklist a certain number of known clones
used by backup products for example.

The definition of blacklisted metrics is defined in `/opt/graphite/conf/blacklist.conf`
and it looks like this :

```basic
^netapp\.(capacity|perf7?)\..+\.vol\..+_CVclone\..+
^netapp\.(capacity|perf)\..+\.vol\..+(0[1-9]|[12][0-9]|3[01])(0[1-9]|1[012])\d\d[0-9]{6}\..+
^netapp\.(capacity|perf7?)\..+\.vol\.cl_.+_(19|20)\d\d(0[1-9]|1[012])( 0[1-9]|[12][0-9]|3[01])[0-9]{6}\..+
^netapp\.(capacity|perf7?)\..+\.vol\.sdw_cl_.+\..+
^netapp\.(perf)\..+\.vol\.MDV_CRS_.+\..+
^netapp\.(perf)\..+\.vol\.MDV_aud_.+\..+
```

You can add your own regular expressions manually, but there is no support for this in
the web interface yet.
